You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@dolphinscheduler.apache.org by li...@apache.org on 2022/01/11 17:20:21 UTC

[dolphinscheduler] branch dev updated: Improvement: improve Pong.java mistake (#7822)

This is an automated email from the ASF dual-hosted git repository.

lidongdai pushed a commit to branch dev
in repository https://gitbox.apache.org/repos/asf/dolphinscheduler.git


The following commit(s) were added to refs/heads/dev by this push:
     new 0cfb204  Improvement: improve Pong.java mistake (#7822)
0cfb204 is described below

commit 0cfb2043cf340e08e212c2e3937d9912bff3fcc8
Author: xuhhui <xu...@cmss.chinamobile.com>
AuthorDate: Wed Jan 12 01:20:13 2022 +0800

    Improvement: improve Pong.java mistake (#7822)
---
 .../main/java/org/apache/dolphinscheduler/remote/command/Pong.java  | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/dolphinscheduler-remote/src/main/java/org/apache/dolphinscheduler/remote/command/Pong.java b/dolphinscheduler-remote/src/main/java/org/apache/dolphinscheduler/remote/command/Pong.java
index 1b51373..5ed762f 100644
--- a/dolphinscheduler-remote/src/main/java/org/apache/dolphinscheduler/remote/command/Pong.java
+++ b/dolphinscheduler-remote/src/main/java/org/apache/dolphinscheduler/remote/command/Pong.java
@@ -38,7 +38,7 @@ public class Pong implements Serializable {
     private static final byte[] EMPTY_BODY_ARRAY = new byte[0];
 
     /**
      *  ping byte buffer
      */
     private static final ByteBuf PONG_BUF;
 
@@ -53,10 +53,10 @@ public class Pong implements Serializable {
     }
 
     /**
-     *  ping content
+     *  pong content
      * @return result
      */
-    public static ByteBuf pingContent(){
+    public static ByteBuf pongContent(){
         return PONG_BUF.duplicate();
     }
@@ -38,7 +38,7 @@ public class Pong implements Serializable {
 
     /**
-     *  ping byte buffer
+     *  pong byte buffer
      */
     private static final ByteBuf PONG_BUF;